==> ucam-identitylib-1.0.16.tar.gz: ucam-identitylib-1.0.16/identitylib/card_client/models/__init__.py <==
# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from identitylib.card_client.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from identitylib.card_client.model.api_exception import APIException
from identitylib.card_client.model.available_barcode import AvailableBarcode
from identitylib.card_client.model.card import Card
from identitylib.card_client.model.card_identifier import CardIdentifier
from identitylib.card_client.model.card_logo import CardLogo
from identitylib.card_client.model.card_note import CardNote
from identitylib.card_client.model.card_request import CardRequest
from identitylib.card_client.model.card_request_distinct_values import CardRequestDistinctValues
from identitylib.card_client.model.card_request_summary import CardRequestSummary
from identitylib.card_client.model.card_summary import CardSummary
from identitylib.card_client.model.list200_response import List200Response
from identitylib.card_client.model.permissions_list200_response import PermissionsList200Response
from identitylib.card_client.model.v1beta1_available_barcodes_batch200_response import V1beta1AvailableBarcodesBatch200Response
from identitylib.card_client.model.v1beta1_available_barcodes_batch200_response_details import V1beta1AvailableBarcodesBatch200ResponseDetails
from identitylib.card_client.model.v1beta1_available_barcodes_batch200_response_details_invalid_inner import V1beta1AvailableBarcodesBatch200ResponseDetailsInvalidInner
from identitylib.card_client.model.v1beta1_available_barcodes_batch_request import V1beta1AvailableBarcodesBatchRequest
from identitylib.card_client.model.v1beta1_available_barcodes_create_request import V1beta1AvailableBarcodesCreateRequest
from identitylib.card_client.model.v1beta1_available_barcodes_list200_response import V1beta1AvailableBarcodesList200Response
from identitylib.card_client.model.v1beta1_card_logos_list200_response import V1beta1CardLogosList200Response
from identitylib.card_client.model.v1beta1_card_notes_create_request import V1beta1CardNotesCreateRequest
from identitylib.card_client.model.v1beta1_card_notes_delete200_response import V1beta1CardNotesDelete200Response
from identitylib.card_client.model.v1beta1_card_notes_delete_request import V1beta1CardNotesDeleteRequest
from identitylib.card_client.model.v1beta1_card_notes_list200_response import V1beta1CardNotesList200Response
from identitylib.card_client.model.v1beta1_card_requests_bulk_update200_response import V1beta1CardRequestsBulkUpdate200Response
from identitylib.card_client.model.v1beta1_card_requests_bulk_update200_response_details_inner import V1beta1CardRequestsBulkUpdate200ResponseDetailsInner
from identitylib.card_client.model.v1beta1_card_requests_bulk_update_request import V1beta1CardRequestsBulkUpdateRequest
from identitylib.card_client.model.v1beta1_card_requests_bulk_update_request_updates_inner import V1beta1CardRequestsBulkUpdateRequestUpdatesInner
from identitylib.card_client.model.v1beta1_card_requests_bulk_update_request_updates_inner_fields import V1beta1CardRequestsBulkUpdateRequestUpdatesInnerFields
from identitylib.card_client.model.v1beta1_card_requests_bulk_update_request_updates_inner_identifiers_inner import V1beta1CardRequestsBulkUpdateRequestUpdatesInnerIdentifiersInner
from identitylib.card_client.model.v1beta1_card_requests_create_request import V1beta1CardRequestsCreateRequest
from identitylib.card_client.model.v1beta1_card_requests_list200_response import V1beta1CardRequestsList200Response
from identitylib.card_client.model.v1beta1_card_requests_update_request import V1beta1CardRequestsUpdateRequest
from identitylib.card_client.model.v1beta1_card_rfid_data_config_list200_response import V1beta1CardRfidDataConfigList200Response
from identitylib.card_client.model.v1beta1_card_rfid_data_config_list200_response_results_inner import V1beta1CardRfidDataConfigList200ResponseResultsInner
from identitylib.card_client.model.v1beta1_cards_filter_request import V1beta1CardsFilterRequest
from identitylib.card_client.model.v1beta1_cards_list200_response import V1beta1CardsList200Response
from identitylib.card_client.model.v1beta1_cards_update_request import V1beta1CardsUpdateRequest
from identitylib.card_client.model.v1beta1_college_institution_ids_list200_response import V1beta1CollegeInstitutionIdsList200Response
from identitylib.card_client.model.validation_error import ValidationError

==> ucam-identitylib-1.1.0.tar.gz: ucam-identitylib-1.1.0/identitylib/card_client/models/__init__.py <==
# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from identitylib.card_client.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from identitylib.card_client.model.api_exception import APIException
from identitylib.card_client.model.available_barcode import AvailableBarcode
from identitylib.card_client.model.card import Card
from identitylib.card_client.model.card_identifier import CardIdentifier
from identitylib.card_client.model.card_logo import CardLogo
from identitylib.card_client.model.card_note import CardNote
from identitylib.card_client.model.card_request import CardRequest
from identitylib.card_client.model.card_request_distinct_values import CardRequestDistinctValues
from identitylib.card_client.model.card_request_summary import CardRequestSummary
from identitylib.card_client.model.card_summary import CardSummary
from identitylib.card_client.model.list200_response import List200Response
from identitylib.card_client.model.permissions_list200_response import PermissionsList200Response
from identitylib.card_client.model.v1beta1_available_barcodes_batch200_response import V1beta1AvailableBarcodesBatch200Response
from identitylib.card_client.model.v1beta1_available_barcodes_batch200_response_details import V1beta1AvailableBarcodesBatch200ResponseDetails
from identitylib.card_client.model.v1beta1_available_barcodes_batch200_response_details_invalid_inner import V1beta1AvailableBarcodesBatch200ResponseDetailsInvalidInner
from identitylib.card_client.model.v1beta1_available_barcodes_batch_request import V1beta1AvailableBarcodesBatchRequest
from identitylib.card_client.model.v1beta1_available_barcodes_create_request import V1beta1AvailableBarcodesCreateRequest
from identitylib.card_client.model.v1beta1_available_barcodes_list200_response import V1beta1AvailableBarcodesList200Response
from identitylib.card_client.model.v1beta1_card_identifiers_list200_response import V1beta1CardIdentifiersList200Response
from identitylib.card_client.model.v1beta1_card_identifiers_update200_response import V1beta1CardIdentifiersUpdate200Response
from identitylib.card_client.model.v1beta1_card_identifiers_update_request import V1beta1CardIdentifiersUpdateRequest
from identitylib.card_client.model.v1beta1_card_logos_list200_response import V1beta1CardLogosList200Response
from identitylib.card_client.model.v1beta1_card_notes_create_request import V1beta1CardNotesCreateRequest
from identitylib.card_client.model.v1beta1_card_notes_delete_request import V1beta1CardNotesDeleteRequest
from identitylib.card_client.model.v1beta1_card_notes_list200_response import V1beta1CardNotesList200Response
from identitylib.card_client.model.v1beta1_card_requests_bulk_update200_response import V1beta1CardRequestsBulkUpdate200Response
from identitylib.card_client.model.v1beta1_card_requests_bulk_update200_response_details_inner import V1beta1CardRequestsBulkUpdate200ResponseDetailsInner
from identitylib.card_client.model.v1beta1_card_requests_bulk_update_request import V1beta1CardRequestsBulkUpdateRequest
from identitylib.card_client.model.v1beta1_card_requests_bulk_update_request_updates_inner import V1beta1CardRequestsBulkUpdateRequestUpdatesInner
from identitylib.card_client.model.v1beta1_card_requests_bulk_update_request_updates_inner_fields import V1beta1CardRequestsBulkUpdateRequestUpdatesInnerFields
from identitylib.card_client.model.v1beta1_card_requests_bulk_update_request_updates_inner_identifiers_inner import V1beta1CardRequestsBulkUpdateRequestUpdatesInnerIdentifiersInner
from identitylib.card_client.model.v1beta1_card_requests_create_request import V1beta1CardRequestsCreateRequest
from identitylib.card_client.model.v1beta1_card_requests_list200_response import V1beta1CardRequestsList200Response
from identitylib.card_client.model.v1beta1_card_requests_update_request import V1beta1CardRequestsUpdateRequest
from identitylib.card_client.model.v1beta1_card_rfid_data_config_list200_response import V1beta1CardRfidDataConfigList200Response
from identitylib.card_client.model.v1beta1_card_rfid_data_config_list200_response_results_inner import V1beta1CardRfidDataConfigList200ResponseResultsInner
from identitylib.card_client.model.v1beta1_cards_filter200_response import V1beta1CardsFilter200Response
from identitylib.card_client.model.v1beta1_cards_filter_request import V1beta1CardsFilterRequest
from identitylib.card_client.model.v1beta1_cards_list200_response import V1beta1CardsList200Response
from identitylib.card_client.model.v1beta1_cards_update_request import V1beta1CardsUpdateRequest
from identitylib.card_client.model.v1beta1_college_institution_ids_list200_response import V1beta1CollegeInstitutionIdsList200Response
from identitylib.card_client.model.validation_error import ValidationError
